==> scala_2.5.0.orig.tar.gz: scala-2.5.0-final/src/library/scala/collection/jcl/IterableWrapper.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2006-2007, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: IterableWrapper.scala 10572 2007-03-30 06:23:12Z mcdirmid $

package scala.collection.jcl;

/** A wrapper around a Java collection that only supports remove mutations.
 *
 *  @author Sean McDirmid 
 */
trait IterableWrapper[A] extends MutableIterable[A] {
  protected def underlying: java.util.Collection;
  override def remove(a: A) = underlying.remove(a);
  override def removeAll(that: Iterable[A]) = that match {
    case that: IterableWrapper[_] => underlying.removeAll(that.underlying);
    case _ => super.removeAll(that);
  }
  override def retainAll(that : Iterable[A]) = that match {
    case that : IterableWrapper[_] => underlying.retainAll(that.underlying);
    case _ => super.retainAll(that);
  }
  //override def size = underlying.size;
  override def isEmpty = underlying.isEmpty;
  override def clear = underlying.clear;
  override def elements : MutableIterator[A] = new IteratorWrapper(underlying.iterator);
  class IteratorWrapper(underlying : java.util.Iterator) extends MutableIterator[A] {
    // val underlying = IterableWrapper.this.underlying.iterator;
    def hasNext = underlying.hasNext;
    def next = underlying.next.asInstanceOf[A];
    def remove = underlying.remove;
  }

}

==> scala_2.6.1.orig.tar.gz: scala-2.6.1-final/src/library/scala/collection/jcl/IterableWrapper.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2006-2007, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: IterableWrapper.scala 12886 2007-09-17 16:36:10Z mcdirmid $

package scala.collection.jcl;

/** A wrapper around a Java collection that only supports remove mutations.
 *
 *  @author Sean McDirmid 
 */
trait IterableWrapper[A] extends MutableIterable[A] {
  def underlying: java.util.Collection;
  override def remove(a: A) = underlying.remove(a);
  override def removeAll(that: Iterable[A]) = that match {
    case that: IterableWrapper[_] => underlying.removeAll(that.underlying);
    case _ => super.removeAll(that);
  }
  override def retainAll(that : Iterable[A]) = that match {
    case that : IterableWrapper[_] => underlying.retainAll(that.underlying);
    case _ => super.retainAll(that);
  }
  override def size = underlying.size;
  override def isEmpty = underlying.isEmpty;
  override def clear = underlying.clear;
  override def elements : MutableIterator[A] = new MutableIterator.Wrapper[A](underlying.iterator);
/* moved to MutableIterator
  class IteratorWrapper(underlying : java.util.Iterator) extends MutableIterator[A] {
    // val underlying = IterableWrapper.this.underlying.iterator;
    def hasNext = underlying.hasNext;
    def next = underlying.next.asInstanceOf[A];
    def remove = underlying.remove;
  }
*/
  
}
